==> mono-2.4.3.tar.bz2: mono-2.4.3/mcs/class/System.Web/System.Web/NoParamsInvoker.cs <==
// 
// System.Web.NoParamsInvoker - proxy used to invoke wired up events without parameters
//				as if they had parameters.
//
// Authors:
// 	Gonzalo Paniagua Javier (gonzalo@ximian.com)
//
// (c) 2003 Ximian, Inc. (http://www.ximian.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.Reflection;
namespace System.Web
{
	delegate void NoParamsDelegate ();
	class NoParamsInvoker
	{
		EventHandler faked;
		NoParamsDelegate real;

		public NoParamsInvoker (object o, MethodInfo method)
		{
			if (method.IsStatic)
				real = (NoParamsDelegate) Delegate.CreateDelegate (
					typeof (NoParamsDelegate), method);
			else
				real = (NoParamsDelegate) Delegate.CreateDelegate (
#if NET_2_0
						typeof (NoParamsDelegate), o, method);
#else
						typeof (NoParamsDelegate), o, method.Name);
#endif
			 faked = new EventHandler (InvokeNoParams);
		}

		void InvokeNoParams (object o, EventArgs args)
		{
			real ();
		}

		public EventHandler FakeDelegate {
			get { return faked; }
		}
	}
}

==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/System.Web/System.Web/NoParamsInvoker.cs <==
// 
// System.Web.NoParamsInvoker - proxy used to invoke wired up events without parameters
//				as if they had parameters.
//
// Authors:
// 	Gonzalo Paniagua Javier (gonzalo@ximian.com)
//
// (c) 2003 Ximian, Inc. (http://www.ximian.com)
// (c) 2003-2009 Novell, Inc (http://novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.Reflection;
namespace System.Web
{
	delegate void NoParamsDelegate ();
	sealed class NoParamsInvoker
	{
		EventHandler faked;
		NoParamsDelegate real;

		public NoParamsInvoker (object o, MethodInfo method)
		{
			if (method.IsStatic)
				real = (NoParamsDelegate) Delegate.CreateDelegate (
					typeof (NoParamsDelegate), method);
			else
				real = (NoParamsDelegate) Delegate.CreateDelegate (typeof (NoParamsDelegate), o, method);
			 faked = new EventHandler (InvokeNoParams);
		}

		void InvokeNoParams (object o, EventArgs args)
		{
			real ();
		}

		public EventHandler FakeDelegate {
			get { return faked; }
		}
	}
}
